.. terminusgps-notifier documentation master file, created by
   sphinx-quickstart on Thu Jul 31 16:10:36 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

terminusgps-notifier documentation
==================================

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    settings.rst
    usage.rst
